#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://gstreamer.freedesktop.org
# source location    : http://gstreamer.freedesktop.org/src/gst-plugins-bad/gst-plugins-bad-0.10.23.tar.bz2
# last revised       : 24.2.2012
# dep                : 

softname='gst-plugins-bad'
softversion='0.10.23'
packageversion='72.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://gstreamer.freedesktop.org/src/gst-plugins-bad/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
               |-----handy-ruler------------------------------------------------------|
gst-plugins-bad: gst-plugins-bad - a set of plug-ins that need more quality
gst-plugins-bad: 
gst-plugins-bad: GStreamer Bad Plug-ins is a set of plug-ins that aren't up to par
gst-plugins-bad: compared to the rest. They might be close to being good quality, but
gst-plugins-bad: they're missing something - be it a good code review, some
gst-plugins-bad: documentation, a set of tests, a real live maintainer, or some actual
gst-plugins-bad: wide use.
gst-plugins-bad: 
gst-plugins-bad: plugins:alsaspdif,apexsink,bz2,cdaudio,mms,mplex,musepack,
gst-plugins-bad: trm,neonhttpsrc,resindvd,rsvg,sdl
gst-plugins-bad: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
#patch -p1 < ../gst-plugins-bad-0.10.22-mjpegtools-2.0.patch

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# create the split package for libraries who need dependencies
cd $buildir
mkdir -p $softname-extra-$softversion-$arch-$packageversion/usr/lib/gstreamer-0.10
mkdir -p $softname-extra-$softversion-$arch-$packageversion/install
cat <<EOF > $softname-extra-$softversion-$arch-$packageversion/install/slack-desc
                     |-----handy-ruler------------------------------------------------------|
gst-plugins-bad-extra: gst-plugins-bad-extra - a set of plug-ins that need more quality
gst-plugins-bad-extra: 
gst-plugins-bad-extra: GStreamer Bad Plug-ins is a set of plug-ins that aren't up to par
gst-plugins-bad-extra: compared to the rest. They might be close to being good quality, but
gst-plugins-bad-extra: they're missing something - be it a good code review, some
gst-plugins-bad-extra: documentation, a set of tests, a real live maintainer, or some actual
gst-plugins-bad-extra: wide use.
gst-plugins-bad-extra: 
gst-plugins-bad-extra: plugins:amrwbenc,dirac,faac,faad,jack,jp2k,kate,libdca,mpeg2enc,
gst-plugins-bad-extra: soundtouch,schro,xvid
gst-plugins-bad-extra: 
EOF
liste="amrwbenc dirac dtsdec faac faad jack jp2k kate mpeg2enc schro soundtouch xvid"
for name in $liste; do
	echo "move libgst${name} in the extra package"
	mv -v $dest/usr/lib/gstreamer-0.10/libgst${name}* $softname-extra-$softversion-$arch-$packageversion/usr/lib/gstreamer-0.10
done
#mv -v $dest/usr/lib/gstreamer-0.10/libresindvd* $softname-extra-$softversion-$arch-$packageversion/usr/lib/gstreamer-0.10
echo "create the extra package"
cd $softname-extra-$softversion-$arch-$packageversion
makepkg -l y -c n $buildir/$softname-extra-$softversion-$arch-$packageversion.txz
cd ..
echo "generate md5sum for extra package"
md5sum $softname-extra-$softversion-$arch-$packageversion.txz > $package.md5
rm -rf $softname-extra-$softversion-$arch-$packageversion

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   ABOUT-NLS INSTALL RELEASE REQUIREMENTS README COPYING AUTHORS NEWS ChangeLog\
   $dest/usr/doc/$softname-$softversion
        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,expat,fontconfig,freetype,gcc,glib2,gst-plugins-base,gstreamer,gtk+2,\
libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libcdaudio,libcroco,libdvdread,libdvdnav\
libexif,libglade,libgsf,libiptcdata,libjpeg,libmpcdec,\
liboil,libpng,libxcb,libxml2,pango,pixman,xcb-util,zlib" > $package.dep

echo -e "amrwb,cxxlibs|gcc-g++,dirac,faac,faad2,gcc,glib2,\
gst-plugins-bad,gst-plugins-base,gstreamer,jack,jasper,libdca,\
libjpeg,libkate,liboil,libxml2,mjpegtools,schroedinger,soundtouch,xvidcore,zlib" > $softname-extra-$softversion-$arch-$packageversion.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/gst-plugins-bad/source/build-gst-plugins-bad.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
